#calculate DnDs between Hcor reference and Hham 10 updated reference in Hcor space
#code based off hanc/redvsgreenHcor/whole_genome_statistics/codeml/whole-genome_v2/runlog.sh
#difference is it uses the 3ix21 version of the Hcor GFF, which is very similar to the 19viii21 version but has a few more genes manually annotated

ln -s ~/bicycle_classifier/selection/DnDs_19viii21/5552-DS-0013_60X_realigned_MPILEUP_final_pseudoref.fasta .
ln -s ~/bicycle_classifier/selection/DnDs_19viii21/hormaphis_cornu_26Sep2017_PoQx8.fasta .
cp ~/bicycle_classifier/selection/DnDs_19viii21/run_codeml_withlnL.sh .
cp ~/bicycle_classifier/selection/DnDs_19viii21/run_codeml.sh .
cp ~/bicycle_classifier/selection/DnDs_19viii21/fasta_to_phylip.sh .
cp ~/bicycle_classifier/selection/DnDs_19viii21/clean_names.sh .
cp ~/bicycle_classifier/selection/DnDs_19viii21/transcript_alignment.sh .

#need to position sort GFF within each transcript. scaffold and gene and transcript order doesn't matter and can be intermingled
awk '{if ($3 == "CDS") {print;};}' Augustus.updated_w_annots.3ix21_final.gff3 | sort -k1,1V -k4,4n > Augustus.updated_w_annots.3ix21_final_sorted.gff3

#get cds sequences for each individual
for i in *.fasta
do 
   prefix=${i//.fasta/}
   bsub -o log.txt -We 10 "~/bin/RandomScripts/constructCDSesFromGFF3.pl -i ${i} -g \
      Augustus.updated_w_annots.3ix21_final_sorted.gff3 > ${prefix}_cds.fasta"
done

#split the cds into two haplotypes. just use one copy for each reference
for i in *_cds.fasta
do 
   base="$(basename $i)"
   prefix=${base//.fasta/}
   bsub -o log.txt -We 10 "~/bin/RandomScripts/fakeHaplotype.pl -i ${i} -s 42 > ${prefix}_haplotype1.fasta"
   bsub -o log.txt -We 10 "~/bin/RandomScripts/fakeHaplotype.pl -i ${i} -s 42 -a > ${prefix}_haplotype2.fasta"
done
mkdir extra_refs
mv 5552-DS-0013_60X_realigned_MPILEUP_final_pseudoref_cds_haplotype2.fasta extra_refs/
mv hormaphis_cornu_26Sep2017_PoQx8_cds_haplotype2.fasta extra_refs/

#list of all the transcripts
grep "^>" hormaphis_cornu_26Sep2017_PoQx8_cds_haplotype1.fasta | cut -c2- > hormaphis_cornu_26Sep2017_PoQx8_all_genes_cds.transcripts.txt

#make alignment of transcripts for each gene (split into 50 chunks to run faster)
mkdir transcript_split
split -l$((`wc -l < hormaphis_cornu_26Sep2017_PoQx8_all_genes_cds.transcripts.txt`/50)) \
   hormaphis_cornu_26Sep2017_PoQx8_all_genes_cds.transcripts.txt transcript_split/hormaphis_cornu_26Sep2017_PoQx8_all_genes_cds.transcripts -da 2
mkdir transcript_alignment
mkdir intermediate
counter=0
for i in transcript_split/hormaphis_cornu_26Sep2017_PoQx8_all_genes_cds.transcripts*
do
   bsub -n 4 -J alignment -o log.txt "./transcript_alignment.sh $i $counter"
   let counter=counter+1
done

#clean up the alignment names
bsub -o log.txt ./clean_names.sh

#change all Ns and -'s to ? for codeml input
#reformat to phylip sequential
bsub -o log.txt -n 8 "./fasta_to_phylip.sh" #makes two folders!

#run codeml (might need to copy the all_cds_phylip folder to a computer node /scratch/hanc through bsub -Is and run there, then copy result back. the many intermediate files are a problem for i/o speed)
cd all_cds_phylip
cp ~/redvsgreenHcor/whole_genome_statistics/codeml/bicycle/bicycle_phylip/codeml.ctl .
ls *phy > gene_list.txt
bsub -o log.txt "../run_codeml.sh gene_list.txt"
cd ..

#####do not need to do this because not looking at which genes significantly DnDs>1 
#re-run codeml to calculate LRT for each gene. To do this, ran codeml twice, once with omega_fixed=0 (estimate omega) and once with omega_fixed=1 (set DnDs to 1)
#and output lnL in both cases
cp ~/redvsgreenHcor/whole_genome_statistics/codeml/bicycle/bicycle_phylip/codeml.ctl .
#manually changed to kappa=2; omega=1 

#estimate omega (same as the codeml run above except output lnL and use kappa=2 as the initial kappa; this doesn't seem to matter much)
mkdir all_cds_phylip_estimate_dnds
cd all_cds_phylip_estimate_dnds/
ln -s ../all_cds_phylip/*.phy .
cp ../codeml.ctl .
ls *phy > gene_list.txt
bsub -o ../log_estimate.txt "../run_codeml_withlnL.sh gene_list.txt ../Hcor_Hham_codeml_all_genes_estimate_dnds.txt"
cd ..

#fix omega to 1 (DnDs always 1)
mkdir all_cds_phylip_dnds1
cd all_cds_phylip_dnds1/
ln -s ../all_cds_phylip/*.phy .
#manually change to fix_omega=1 in codeml.ctl
cp ../codeml.ctl .
ls *phy > gene_list.txt
bsub -o ../log_fixed.txt "../run_codeml_withlnL.sh gene_list.txt ../Hcor_Hham_codeml_all_genes_dnds1.txt"
cd ..
